//
//  MusicStatusViewController.m
//  MusicStatus
//
//  Created by Kent Sutherland on 10/12/08.
//  Copyright Kent Sutherland 2008. All rights reserved.
//

#import "MusicStatusViewController.h"
#import <AudioToolbox/AudioToolbox.h>

#if TARGET_IPHONE_SIMULATOR
#error Run on a device to test
#endif

@interface MusicStatusViewController (Private)
- (void)_updatePlayingStatus;
@end

@implementation MusicStatusViewController

- (void)dealloc
{
	[[NSNotificationCenter defaultCenter] removeObserver:self];
	
    [super dealloc];
}

- (void)notificationReceived:(NSNotification *)note
{
	[self _updatePlayingStatus];
}

- (void)viewDidLoad
{
	//There must be an audio session running in order to call AudioSessionGetProperty successfully
	OSStatus status = AudioSessionInitialize(NULL, NULL, NULL, NULL);
	
	if (status != kAudioSessionNoError) {
		NSLog(@"AudioSessionInitialize failed! %d", status);
	}
	
	//This will update the playing status if the user double-presses the home button and changes music playback in the floating mini-player
	[[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(notificationReceived:) name:UIApplicationDidBecomeActiveNotification object:nil];
	
	[super viewDidLoad];
}

- (void)viewWillAppear:(BOOL)animated
{
	[self _updatePlayingStatus];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

#pragma mark Private
#pragma mark -

- (void)_updatePlayingStatus
{
	UInt32 isPlaying;
	UInt32 propertySize = sizeof(isPlaying);
	OSStatus status;
	
	status = AudioSessionGetProperty(kAudioSessionProperty_OtherAudioIsPlaying, &propertySize, &isPlaying);
	
	if (status != kAudioSessionNoError) {
		NSLog(@"AudioSessionGetProperty failed! %d", status);
	}
	
	if (propertySize != sizeof(isPlaying)) {
		NSLog(@"AudioSessionGetProperty returned a bad property size.");
	}
	
	[_statusLabel setText:isPlaying ? @"Audio Playing" : @"No Audio Playing"];
}

@end
